View source: R/functions_qSIP_MAGs.R
| incorporators_taxonomy | R Documentation |
This function provides a table with MAGs and their corresponding GTDB taxonomy as an output. This would be useful in identifying the taxa that have incorporation
incorporators_taxonomy(taxonomy, bootstrapped_AFE_table)
taxonomy |
A taxonomy tibble obtained in the markdown. This taxonomy tibble is typically a concatenated list of archaeal and bacterial taxonomy from GTDB-Tk Please check GTDB-Tk documentation for running the tool |
bootstrapped_AFE_table |
A data frame indicating bootstrapped atom fraction excess values |
A tibble with two columns, OTU and Taxonomy, with taxonomy of the incorporator MAGs
data(taxonomy_tibble,df_atomX_boot)
### Making incorporator taxonomy list
incorporator_list = incorporators_taxonomy(taxonomy = taxonomy_tibble,
bootstrapped_AFE_table = df_atomX_boot)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.