Learn R Programming

SIPmg (version 3.0)

incorporators_taxonomy: Isotope incorporator list with GTDB taxonomy

Description

This function provides a table with MAGs and their corresponding GTDB taxonomy as an output. This would be useful in identifying the taxa that have incorporation

Usage

incorporators_taxonomy(taxonomy, bootstrapped_AFE_table)

Value

A tibble with two columns, OTU and Taxonomy, with taxonomy of the incorporator MAGs

Arguments

taxonomy

A taxonomy tibble obtained in the markdown. This taxonomy tibble is typically a concatenated list of archaeal and bacterial taxonomy from GTDB-Tk Please check GTDB-Tk documentation for running the tool

bootstrapped_AFE_table

A data frame indicating bootstrapped atom fraction excess values

Examples

Run this code
data(taxonomy_tibble,df_atomX_boot)

# \donttest{

### Making incorporator taxonomy list
incorporator_list = incorporators_taxonomy(taxonomy = taxonomy_tibble,
         bootstrapped_AFE_table = df_atomX_boot)
# }

Run the code above in your browser using DataLab